"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useStateDataList = void 0;
const React = require("react");
const react_1 = require("react");
const create_single_rhino_state_1 = require("./create-single-rhino-state");
const StateDataContext = react_1.createContext({});
/**
 *
 * Provider Component which makes the states available to all the nested components
 */
const RhinoStateProvider = ({ children, stateDataList, }) => {
    const ProviderList = Object.values(stateDataList).map((stateData) => stateData.provider);
    // Combining all providers into a single provider
    const RootProvider = ProviderList.reduce((ProviderAccumulator, Provider) => {
        return ({ children }) => (React.createElement(ProviderAccumulator, null,
            React.createElement(Provider, null, children)));
    });
    return React.createElement(RootProvider, null, children);
};
const RhinoProvider = ({ children, initialStates: initialStatesObject, }) => {
    const stateDataList = {};
    Object.keys(initialStatesObject).forEach((key) => {
        const initialValue = initialStatesObject[key];
        const { Provider, useStateValue, useStateUpdate } = create_single_rhino_state_1.default(initialValue);
        stateDataList[key] = {
            provider: Provider,
            stateHook: useStateValue,
            updaterHook: useStateUpdate,
        };
    });
    return (React.createElement(StateDataContext.Provider, { value: stateDataList },
        React.createElement(RhinoStateProvider, { stateDataList: stateDataList }, children)));
};
const useStateDataList = () => react_1.useContext(StateDataContext);
exports.useStateDataList = useStateDataList;
exports.default = RhinoProvider;
